@@ -1,6 +1,7 @@
 tepBADA <-
-function(DATA,scaleFlag=TRUE,centerFlag=TRUE,DESIGN=NULL,make_design_nominal=TRUE,group.masses=NULL,ind.masses=NULL,weights=NULL,graphs=TRUE,k=0){
+function(DATA,scale=TRUE,center=TRUE,DESIGN=NULL,make_design_nominal=TRUE,group.masses=NULL,ind.masses=NULL,weights=NULL,graphs=TRUE,k=0){
 		
+	
 	DESIGN <- texpoDesignCheck(DATA,DESIGN,make_design_nominal)
 	colDESIGN <- colnames(DESIGN)
 	massedDESIGN<-t(t(DESIGN) * (1/(colSums(DESIGN))))
@@ -10,7 +11,9 @@ function(DATA,scaleFlag=TRUE,centerFlag=TRUE,DESIGN=NULL,make_design_nominal=TRU
 	DATA <- as.matrix(DATA)
 	XMW <- computeMW(DATA,masses=ind.masses,weights=weights)
 
-	R <- scale(t(massedDESIGN) %*% DATA,scale=scaleFlag,center=centerFlag)
+	R <- expo.scale(t(massedDESIGN) %*% DATA,scale=scale,center=center)
+	this.center <- attributes(R)$`scaled:center`
+	this.scale <- attributes(R)$`scaled:scale`	
 	RMW <- computeMW(R,masses=group.masses,weights=weights)
 
 	colnames(R) <- colnames(DATA)
@@ -19,20 +22,12 @@ function(DATA,scaleFlag=TRUE,centerFlag=TRUE,DESIGN=NULL,make_design_nominal=TRU
 	rownames(Rdesign) <- rownames(R)	
 	
 	#res <- corePCA(R,M=RMW$M,W=RMW$W,k=k)
-	res <- epGPCA(R, DESIGN=Rdesign, make_design_nominal=FALSE, scaleFlag = FALSE, centerFlag = FALSE, masses = RMW$M, weights = RMW$W, graphs = FALSE, k = k)
+	res <- epGPCA(R, DESIGN=Rdesign, make_design_nominal=FALSE, scale = FALSE, center = FALSE, masses = RMW$M, weights = RMW$W, graphs = FALSE, k = k)
+	res <- res$ExPosition.Data
+	res$center <- this.center
+	res$scale <- this.scale
 
-	centerSup <- FALSE
-	if(centerFlag){
-		centerSup <- attributes(R)$`scaled:center`
-	}
-	scaleSup <- FALSE
-	if(scaleFlag){
-		scaleSup <- attributes(R)$`scaled:scale`
-	}
-
-	supplementaryRes <- supplementaryRows(DATA,res,center=centerSup,scale=scaleSup)
-	#supplementaryRes <- supplementaryRows(DATA,res,center=centerFlag,scale=scaleFlag)
-	
+	supplementaryRes <- supplementaryRows(DATA,res)
 	res$fii <- supplementaryRes$fii
 	res$dii <- supplementaryRes$dii
 	res$rii <- supplementaryRes$rii
@@ -41,12 +36,9 @@ function(DATA,scaleFlag=TRUE,centerFlag=TRUE,DESIGN=NULL,make_design_nominal=TRU
 	assignments$r2 <- R2(RMW$M,res$di,XMW$M,res$dii)
 	class(assignments) <- c("tepAssign","list")
 	res$assign <- assignments
-	
+
 	#new res here
-	tepPlotInfo <- NULL
-	class(res) <- c("tepBADA","list")	
-	if(graphs){
-		tepPlotInfo <- tepGraphHandler(res,DATA,DESIGN,main)
-	}
+	class(res) <- c("tepBADA","list")		
+	tepPlotInfo <- tepGraphs(res=res,DESIGN=DESIGN,main=main,graphs=graphs)
 	return(tepOutputHandler(res=res,tepPlotInfo=tepPlotInfo))
 }
